import psycopg2
import sys
from custom import faker_options_container
from helpers import fake2db_logger, str_generator
from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT

logger, extra_information = fake2db_logger()
d = extra_information

try:
    from faker import Factory
except ImportError:
    logger.error('faker package not found onto python packages, please run : \
    pip install -r requirements.txt  \
    on the root of the project')


class Fake2dbPostgresqlHandler():
    faker = Factory.create()

    def fake2db_initiator(self, number_of_rows, **connection_kwargs):
        '''Main handler for the operation
        '''
        rows = number_of_rows
        cursor, conn = self.database_caller_creator(number_of_rows, **connection_kwargs)

        self.data_filler_simple_registration(rows, cursor, conn)
        self.data_filler_detailed_registration(rows, cursor, conn)
        self.data_filler_company(rows, cursor, conn)
        self.data_filler_user_agent(rows, cursor, conn)
        self.data_filler_customer(rows, cursor, conn)
        cursor.close()
        conn.close()

    def database_caller_creator(self, number_of_rows, username, password, host, port, name=None, custom=None):
        '''creates a postgresql db
        returns the related connection object
        which will be later used to spawn the cursor
        '''
        cursor = None
        conn = None

        if name:
            dbname = name
        else:
            dbname = 'postgresql_' + str_generator(self).lower()
        try:
            # createdb
            conn = psycopg2.connect(
                user=username, password=password, host=host, port=port)
            conn.set_isolation_level(ISOLATION_LEVEL_AUTOCOMMIT)
            cur = conn.cursor()
            cur.execute('CREATE DATABASE %s;' % dbname)
            cur.close()
            conn.close()
            # reconnect to the new database
            conn = psycopg2.connect(user=username, password=password,
                                    host=host, port=port, database=dbname)
            cursor = conn.cursor()
            logger.warning('Database created and opened succesfully: %s' % dbname, extra=d)
        except Exception as err:
            logger.error(err, extra=d)
            raise

        if custom:
            self.custom_db_creator(number_of_rows, cursor, conn, custom)
            cursor.close()
            conn.close()
            sys.exit(0)

        return cursor, conn

    def custom_db_creator(self, number_of_rows, cursor, conn, custom):
        '''creates and fills the table with simple regis. information
        '''

        custom_d = faker_options_container()
        sqlst = "CREATE TABLE custom (id serial PRIMARY KEY,"
        custom_payload = "INSERT INTO custom ("
        
        # form the sql query that will set the db up
        for c in custom:
            if custom_d.get(c):
                sqlst += " " + c + " " + custom_d[c] + ","
                custom_payload += " " + c + ","
                logger.warning("fake2db found valid custom key provided: %s" % c, extra=d)
            else:
                logger.error("fake2db does not support the custom key you provided.", extra=d )
                sys.exit(1)
                
        # the indice thing is for trimming the last extra comma
        sqlst = sqlst[:-1]
        sqlst += ");"
        custom_payload = custom_payload[:-1]
        custom_payload += ") VALUES ("

        for i in range(0, len(custom)):
            custom_payload += "%s, "
        custom_payload = custom_payload[:-2] + ")"
        cursor.execute(sqlst)
        conn.commit()

        multi_lines = []
        try:
            for i in range(0, number_of_rows):
                multi_lines.append([])
                for c in custom:
                    multi_lines[i].append(getattr(self.faker, c)())
            
            cursor.executemany(custom_payload, multi_lines)
            conn.commit()
            logger.warning('custom Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)
            
    def data_filler_simple_registration(self, number_of_rows, cursor, conn):
        '''creates and fills the table with simple regis. information
        '''

        cursor.execute("CREATE TABLE simple_registration (id serial PRIMARY KEY, email varchar(300), password varchar(300));")
        conn.commit()

        simple_registration_data = []

        try:

            for i in range(0, number_of_rows):
                simple_registration_data.append((self.faker.safe_email(), self.faker.md5(raw_output=False)))
            simple_registration_payload = ("INSERT INTO simple_registration "
                                           "(email, password) "
                                           "VALUES (%s, %s)")
            cursor.executemany(simple_registration_payload, simple_registration_data)
            conn.commit()

            logger.warning('simple_registration Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_detailed_registration(self, number_of_rows, cursor, conn):
        '''creates and fills the table with detailed regis. information
        '''

        cursor.execute(
            "CREATE TABLE detailed_registration "
            "(id serial PRIMARY KEY, email varchar(300), password varchar(300), "
            "lastname varchar(300), name varchar(300), adress varchar(300), phone varchar(300));")
        conn.commit()
        detailed_registration_data = []

        try:

            for i in range(0, number_of_rows):

                detailed_registration_data.append((self.faker.safe_email(), self.faker.md5(raw_output=False), self.faker.last_name(),
                                                   self.faker.first_name(), self.faker.address(), self.faker.phone_number()))

            detailed_registration_payload = ("INSERT INTO detailed_registration "
                                             "(email, password, lastname, name, adress, phone) "
                                             "VALUES (%s, %s, %s, %s, %s, %s)")

            cursor.executemany(detailed_registration_payload, detailed_registration_data)
            conn.commit()
            logger.warning('detailed_registration Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_user_agent(self, number_of_rows, cursor, conn):
        '''creates and fills the table with user agent data
        '''

        cursor.execute(
            "CREATE TABLE user_agent (id serial PRIMARY KEY, ip varchar(300), countrycode varchar(300), useragent varchar(300));")
        conn.commit()

        user_agent_data = []

        try:

            for i in range(0, number_of_rows):

                user_agent_data.append((self.faker.ipv4(), self.faker.country_code(),
                 self.faker.user_agent()))

            user_agent_payload = ("INSERT INTO user_agent "
                               "(ip, countrycode, useragent) "
                               "VALUES (%s, %s, %s)")

            cursor.executemany(user_agent_payload, user_agent_data)
            conn.commit()

            logger.warning('user_agent Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_company(self, number_of_rows, cursor, conn):
        '''creates and fills the table with company data
        '''

        cursor.execute(
            "CREATE TABLE company (id serial PRIMARY KEY, "
            "name varchar(300), sdate varchar(300), email varchar(300), domain varchar(300), city varchar(300));")
        conn.commit()
        company_data = []

        try:
            for i in range(0, number_of_rows):

                company_data.append((self.faker.company(), self.faker.date(pattern="%d-%m-%Y"),
                                     self.faker.company_email(), self.faker.safe_email(), self.faker.city()))

            company_payload = ("INSERT INTO company "
                               "(name, sdate, email, domain, city) "
                               "VALUES (%s, %s, %s, %s, %s)")

            cursor.executemany(company_payload, company_data)
            conn.commit()
            logger.warning('companies Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_customer(self, number_of_rows, cursor, conn):
        '''creates and fills the table with customer data
        '''

        cursor.execute(
            "CREATE TABLE customer (id serial PRIMARY KEY, "
            "name varchar(300), lastname varchar(300), address varchar(300), country varchar(300), "
            "city varchar(300), registry_date varchar(300), birthdate varchar(300), email varchar(300), "
            "phone_number varchar(300), locale varchar(300));")
        conn.commit()

        customer_data = []

        try:
            for i in range(0, number_of_rows):

                customer_data.append((self.faker.first_name(), self.faker.last_name(), self.faker.address(),
                                      self.faker.country(), self.faker.city(), self.faker.date(pattern="%d-%m-%Y"),
                                      self.faker.date(pattern="%d-%m-%Y"), self.faker.safe_email(), self.faker.phone_number(),
                                      self.faker.locale()))

            customer_payload = ("INSERT INTO customer "
                                "(name, lastname, address, country, city, registry_date, "
                                "birthdate, email, phone_number, locale)"
                                "VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)")

            cursor.executemany(customer_payload, customer_data)
            conn.commit()
            logger.warning('customer Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)




import logging
import getpass
import string
import random
import uuid


def fake2db_logger():
    '''creates a logger obj'''
    # Pull the local ip and username for meaningful logging
    username = getpass.getuser()
    
    # Set the logger
    FORMAT = '%(asctime)-15s %(user)-8s %(message)s'
    logging.basicConfig(format=FORMAT)
    extra_information = {'user': username}
    logger = logging.getLogger('fake2db_logger')
    # --------------------
    return logger, extra_information


def str_generator(self):
    '''generates uppercase 8 chars
    '''
    return ''.join(random.choice(string.ascii_uppercase) for i in range(8))

def lower_str_generator(self):
    '''generates lowercase 8 chars
    '''
    return ''.join(random.choice(string.ascii_lowercase) for i in range(8))


def rnd_id_generator(self):
    '''generates a UUID such as :
    UUID('dd1098bd-70ac-40ea-80ef-d963f09f95a7')
    than gets rid of dashes
    '''
    return str(uuid.uuid4()).replace('-', '')



def faker_options_container():
    '''
    Following dictionary is mapped with fake-factory
    providers, so that custom db creation be made with
    faker.

    for detailed info for providers:

    http://fake-factory.readthedocs.org/en/latest/#

    '''
    faker_options = {"name_male": "varchar(200)",
                     "address": "varchar(300)",
                     "am_pm": "varchar(3)",
                     "boolean": "varchar(10)",
                     "opera": "varchar(300)",
                     "paragraph": "varchar(300)",
                     "bs": "varchar(300)",
                     "building_number": "INT",
                     "password": "varchar(300)",
                     "century": "varchar(50)",
                     "phone_number": "varchar(250)",
                     "chrome": "varchar(300)",
                     "postalcode": "varchar(300)",
                     "city": "varchar(300)",
                     "postalcode_plus4": "varchar(300)",
                     "city_prefix": "varchar(300)",
                     "postcode": "varchar(300)",
                     "city_suffix": "varchar(300)",
                     "prefix": "varchar(300)",
                     "color_name": "varchar(300)",
                     "prefix_female": "varchar(300)",
                     "company": "varchar(300)",
                     "prefix_male": "varchar(300)",
                     "company_email": "varchar(300)",
                     "profile": "varchar(300)",
                     "company_suffix": "varchar(300)",
                     "provider": "varchar(300)",
                     "country": "varchar(300)",
                     "country_code": "varchar(300)",
                     "credit_card_expire": "varchar(300)",
                     "credit_card_full": "varchar(300)",
                     "credit_card_number": "varchar(300)",
                     "credit_card_provider": "varchar(300)",
                     "credit_card_security_code": "varchar(300)",
                     "currency_code": "varchar(30)",
                     "date": "varchar(300)",
                     "date_time_ad": "varchar(300)",
                     "date_time_between": "varchar(300)",
                     "date_time_between_dates": "varchar(300)",
                     "random_digit": "INT",
                     "random_digit_not_null": "varchar(300)",
                     "date_time_this_decade": "varchar(300)",
                     "random_digit_not_null_or_empty": "varchar(300)",
                     "date_time_this_month": "varchar(300)",
                     "random_digit_or_empty": "varchar(300)",
                     "date_time_this_year": "varchar(300)",
                     "random_element": "varchar(300)",
                     "day_of_month": "varchar(300)",
                     "random_int": "INT",
                     "day_of_week": "varchar(300)",
                     "random_letter": "varchar(5)",
                     "domain_name": "varchar(300)",
                     "random_number": "INT",
                     "domain_word": "varchar(300)",
                     "ean": "varchar(300)",
                     "rgb_color": "varchar(300)",
                     "ean13": "varchar(300)",
                     "rgb_color_list": "varchar(300)",
                     "ean8": "varchar(300)",
                     "prgb_css_color": "varchar(300)",
                     "email": "varchar(300)",
                     "safari": "varchar(300)",
                     "file_extension": "varchar(300)",
                     "safe_color_name": "varchar(300)",
                     "file_name": "varchar(300)",
                     "safe_email": "varchar(300)",
                     "firefox": "varchar(300)",
                     "safe_hex_color": "varchar(300)",
                     "first_name": "varchar(300)",
                     "secondary_address": "varchar(300)",
                     "first_name_female": "varchar(300)",
                     "first_name_male": "varchar(300)",
                     "sentence": "varchar(300)",
                     "free_email": "varchar(300)",
                     "free_email_domain": "varchar(300)",
                     "sha1": "varchar(300)",
                     "geo_coordinate": "varchar(300)",
                     "sha256": "varchar(300)",
                     "slug": "varchar(300)",
                     "hex_color": "varchar(300)",
                     "ssn": "varchar(300)",
                     "image_url": "varchar(300)",
                     "state": "varchar(300)",
                     "internet_explorer": "varchar(300)",
                     "state_abbr": "varchar(300)",
                     "ipv4": "varchar(300)",
                     "street_address": "varchar(300)",
                     "ipv6": "varchar(300)",
                     "street_name": "varchar(300)",
                     "iso8601": "varchar(300)",
                     "street_suffix": "varchar(300)",
                     "job": "varchar(300)",
                     "suffix": "varchar(300)",
                     "language_code": "varchar(300)",
                     "suffix_female": "varchar(300)",
                     "last_name": "varchar(300)",
                     "suffix_male": "varchar(300)",
                     "last_name_female": "varchar(300)",
                     "text": "varchar(300)",
                     "last_name_male": "varchar(300)",
                     "time": "varchar(300)",
                     "latitude": "varchar(300)",
                     "time_delta": "varchar(300)",
                     "timezone": "varchar(300)",
                     "linux_platform_token": "varchar(300)",
                     "tld": "varchar(300)",
                     "linux_processor": "varchar(300)",
                     "unix_time": "varchar(300)",
                     "locale": "varchar(300)",
                     "uri": "varchar(300)",
                     "longitude": "varchar(300)",
                     "uri_extension": "varchar(300)",
                     "mac_address": "varchar(300)",
                     "uri_page": "varchar(300)",
                     "mac_platform_token": "varchar(300)",
                     "uri_path": "varchar(300)",
                     "mac_processor": "varchar(300)",
                     "url": "varchar(300)",
                     "md5": "varchar(300)",
                     "user_agent": "varchar(300)",
                     "military_apo": "varchar(300)",
                     "user_name": "varchar(300)",
                     "military_dpo": "varchar(300)",
                     "uuid4": "varchar(300)",
                     "military_ship": "varchar(300)",
                     "windows_platform_token": "varchar(300)",
                     "military_state": "varchar(300)",
                     "word": "varchar(300)",
                     "mime_type": "varchar(300)",
                     "words": "varchar(300)",
                     "month": "varchar(300)",
                     "year": "varchar(300)",
                     "month_name": "varchar(300)",
                     "zipcode": "varchar(300)",
                     "name": "varchar(300)",
                     "zipcode_plus4": "varchar(300)",
                     "name_female": "varchar(300)",
    }
    
    return faker_options



import sqlite3
import sys
from custom import faker_options_container
from helpers import fake2db_logger, str_generator, rnd_id_generator

logger, extra_information = fake2db_logger()
d = extra_information

try:
    from faker import Factory
except ImportError:
    logger.error('faker package not found onto python packages, please run : \
    pip install -r requirements.txt  \
    on the root of the project', extra=d)


class DbConnException(Exception):
    """Database Connection or Creation Exception"""


class Fake2dbSqliteHandler():
    faker = Factory.create()

    def fake2db_sqlite_initiator(self, number_of_rows, name=None, custom=None):
        '''Main handler for the operation
        '''
        rows = number_of_rows
        conn = self.database_caller_creator(name)

        if custom:
            self.custom_db_creator(rows, conn, custom)
            conn.close()
            sys.exit(0)
            
        self.data_filler_simple_registration(rows, conn)
        self.data_filler_detailed_registration(rows, conn)
        self.data_filler_company(rows, conn)
        self.data_filler_user_agent(rows, conn)
        self.data_filler_customer(rows, conn)
        conn.close()

    def custom_db_creator(self, number_of_rows, conn, custom):
        '''creates and fills the table with simple regis. information
        '''
        cursor = conn.cursor()
        custom_d = faker_options_container()
        sqlst = '''
        CREATE TABLE custom(id TEXT PRIMARY KEY,'''

        # first one is always ID primary key
        exec_many = 'insert into custom values(?,'
        
        for c in custom:
            if custom_d.get(c):
                sqlst += " " + c + " TEXT, "
                exec_many += '?,'
                logger.warning("fake2db found valid custom key provided: %s" % c, extra=d)
            else:
                logger.error("fake2db does not support the custom key you provided.", extra=d )
                sys.exit(1)
                
        sqlst = sqlst[:-2] + ")"
        cursor.execute(sqlst)   
        conn.commit()
        multi_lines = []
        exec_many = exec_many[:-1] +')'
        
        try:
            for i in range(0, number_of_rows):
                multi_lines.append([rnd_id_generator(self)])
                for c in custom:
                    multi_lines[i].append(getattr(self.faker, c)())
            
            cursor.executemany(exec_many, multi_lines)
            conn.commit()
            logger.warning('custom Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def database_caller_creator(self, name=None):
        '''creates a sqlite3 db
        returns the related connection object
        which will be later used to spawn the cursor
        '''

        try:
            if name:
                database = name + '.db'
            else:
                database = 'sqlite_' + str_generator(self) + '.db'

            conn = sqlite3.connect(database)
            logger.warning('Database created and opened succesfully: %s' % database, extra=d)
        except Exception:
            logger.error('Failed to connect or create database / sqlite3', extra=d)
            raise DbConnException

        return conn
    
    def data_filler_simple_registration(self, number_of_rows, conn):
        '''creates and fills the table with simple regis. information
        '''
        cursor = conn.cursor()

        cursor.execute('''
        CREATE TABLE simple_registration(id TEXT PRIMARY KEY,
        email TEXT , password TEXT)
        ''')
        conn.commit()
        multi_lines = []
        
        try:
            for i in range(0, number_of_rows):
                multi_lines.append((rnd_id_generator(self), self.faker.safe_email(), self.faker.md5(raw_output=False)))
            cursor.executemany('insert into simple_registration values(?,?,?)',multi_lines)
            conn.commit()
            logger.warning('simple_registration Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_detailed_registration(self, number_of_rows, conn):
        '''creates and fills the table with detailed regis. information
        '''
        cursor = conn.cursor()

        cursor.execute('''
        CREATE TABLE detailed_registration(id TEXT PRIMARY KEY,
        email TEXT, password TEXT, lastname TEXT,
        name TEXT, adress TEXT, phone TEXT)
        ''')
        conn.commit()
        multi_lines = []
        
        try:
            for i in range(0, number_of_rows):
                multi_lines.append((rnd_id_generator(self), self.faker.safe_email(),
                                    self.faker.md5(raw_output=False), self.faker.last_name(),
                                    self.faker.first_name(), self.faker.address(), self.faker.phone_number()))
                
            cursor.executemany('insert into detailed_registration values(?,?,?,?,?,?,?)', multi_lines)
            conn.commit()
            logger.warning('detailed_registration Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_user_agent(self, number_of_rows, conn):
        '''creates and fills the table with user agent data
        '''
        cursor = conn.cursor()

        cursor.execute('''
        CREATE TABLE user_agent(id TEXT PRIMARY KEY,
        ip TEXT, countrycode TEXT, useragent TEXT)
        ''')
        conn.commit()
        multi_lines = []
        
        try:
            for i in range(0, number_of_rows):
                multi_lines.append((rnd_id_generator(self), self.faker.ipv4(), self.faker.country_code(),
                                    self.faker.user_agent()))
                
            cursor.executemany('insert into user_agent values(?,?,?,?)', multi_lines)
            conn.commit()
            logger.warning('user_agent Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_company(self, number_of_rows, conn):
        '''creates and fills the table with company data
        '''
        cursor = conn.cursor()

        cursor.execute('''
        CREATE TABLE company(id TEXT PRIMARY KEY,
        name TEXT, sdate TEXT, email TEXT, domain TEXT, city TEXT)
        ''')
        conn.commit()
        multi_lines = []
        
        try:
            for i in range(0, number_of_rows):
                
                multi_lines.append((rnd_id_generator(self), self.faker.company(),
                                    self.faker.date(pattern="%d-%m-%Y"),
                                    self.faker.company_email(), self.faker.safe_email(),
                                    self.faker.city()))
                
            cursor.executemany('insert into company values (?,?,?,?,?,?)', multi_lines)
            conn.commit()
            logger.warning('companies Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_customer(self, number_of_rows, conn):
        '''creates and fills the table with customer data
        '''
        cursor = conn.cursor()
        cursor.execute('''
        CREATE TABLE customer(id TEXT PRIMARY KEY,
        name TEXT, lastname TEXT, address TEXT, country TEXT, city TEXT, registry_date TEXT, birthdate TEXT, email TEXT,
         phone_number TEXT, locale TEXT)
        ''')
        conn.commit()
        multi_lines = []
        
        try:
            for i in range(0, number_of_rows):
                
                multi_lines.append((rnd_id_generator(self), self.faker.first_name(), self.faker.last_name(), self.faker.address(),
                                    self.faker.country(), self.faker.city(), self.faker.date(pattern="%d-%m-%Y"),
                                    self.faker.date(pattern="%d-%m-%Y"), self.faker.safe_email(), self.faker.phone_number(),
                                    self.faker.locale()))
                               
            cursor.executemany('insert into customer values (?,?,?,?,?,?,?,?,?,?,?)', multi_lines)
            conn.commit()
            logger.warning('customer Commits are successful after write job!', extra=d)
        except Exception as e:
            logger.error(e, extra=d)



import couchdb
import sys
from custom import faker_options_container
from helpers import fake2db_logger, lower_str_generator, rnd_id_generator

logger, extra_information = fake2db_logger()
d = extra_information

try:
    from faker import Factory
except ImportError:
    logger.error('faker package not found onto python packages, please run : \
    pip install -r requirements.txt  \
    on the root of the project')


class Fake2dbCouchdbHandler():
    faker = Factory.create()

    def fake2db_couchdb_initiator(self, number_of_rows, name=None, custom=None):
        '''Main handler for the operation
        '''
        rows = number_of_rows
        db = self.database_caller_creator(name)

        if custom:
            self.custom_db_creator(rows, db, custom)
            sys.exit(0)
            
        self.data_filler_simple_registration(rows, db)
        self.data_filler_detailed_registration(rows, db)
        self.data_filler_company(rows, db)
        self.data_filler_user_agent(rows, db)
        self.data_filler_customer(rows, db)

    def database_caller_creator(self, name=None):
        '''creates a couchdb database
        returns the related connection object
        which will be later used to spawn the cursor
        '''

        couch = couchdb.Server()

        if name:
            db = couch.create(name)
        else:
            n = 'couchdb_' + lower_str_generator(self)
            db = couch.create(n)
            logger.warning('couchdb database created with the name: %s', n,
                           extra=d)

        return db

    def custom_db_creator(self, number_of_rows, db, custom):
        try:
            data_list = list()
            custom_d = faker_options_container()
            
            for c in custom:
                if custom_d.get(c):
                    logger.warning("fake2db found valid custom key provided: %s" % c, extra=d)
                else:
                    logger.error("fake2db does not support the custom key you provided.", extra=d )
                    sys.exit(1)
                    
            for i in range(0, number_of_rows):
                dict_c = {"id": rnd_id_generator(self)}
                for c in custom:
                    dict_c[c] = getattr(self.faker, c)()
                          
                db.save(dict_c)

            
            logger.warning('custom Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)
    
    
    def data_filler_simple_registration(self, number_of_rows, db):
        '''creates and fills the table with simple regis. information
        '''

        try:
            simple_registration = db

            for i in range(0, number_of_rows):
                post_simple_reg = {
                    "id": rnd_id_generator(self),
                    "email": self.faker.safe_email(),
                    "password": self.faker.md5(raw_output=False)
                }
                simple_registration.save(post_simple_reg)

            logger.warning(
                'simple_registration Commits are successful after write job!',
                extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_detailed_registration(self, number_of_rows, db):
        '''creates and fills the table with detailed regis. information
        '''

        try:
            detailed_registration = db
            data_list = list()
            for i in range(0, number_of_rows):
                post_det_reg = {
                    "id": rnd_id_generator(self),
                    "email": self.faker.safe_email(),
                    "password": self.faker.md5(raw_output=False),
                    "lastname": self.faker.last_name(),
                    "name": self.faker.first_name(),
                    "adress": self.faker.address(),
                    "phone": self.faker.phone_number()
                }
                detailed_registration.save(post_det_reg)

            logger.warning(
                'detailed_registration Commits are successful after write job!',
                extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_user_agent(self, number_of_rows, db):
        '''creates and fills the table with user agent data
        '''

        try:
            user_agent = db
            data_list = list()
            for i in range(0, number_of_rows):
                post_uo_reg = {
                    "id": rnd_id_generator(self),
                    "ip": self.faker.ipv4(),
                    "countrycode": self.faker.country_code(),
                    "useragent": self.faker.user_agent()
                }
                user_agent.save(post_uo_reg)

            logger.warning(
                'user_agent Commits are successful after write job!',
                extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_company(self, number_of_rows, db):
        '''creates and fills the table with company data
        '''

        try:
            company = db
            data_list = list()
            for i in range(0, number_of_rows):
                post_comp_reg = {
                    "id": rnd_id_generator(self),
                    "name": self.faker.company(),
                    "date": self.faker.date(pattern="%d-%m-%Y"),
                    "email": self.faker.company_email(),
                    "domain": self.faker.safe_email(),
                    "city": self.faker.city()
                }
                company.save(post_comp_reg)

            logger.warning('companies Commits are successful after write job!',
                           extra=d)
        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_customer(self, number_of_rows, db):
        '''creates and fills the table with customer data
        '''

        try:
            customer = db
            data_list = list()
            for i in range(0, number_of_rows):
                post_cus_reg = {
                    "id": rnd_id_generator(self),
                    "name": self.faker.first_name(),
                    "lastname": self.faker.last_name(),
                    "address": self.faker.address(),
                    "country": self.faker.country(),
                    "city": self.faker.city(),
                    "registry_date": self.faker.date(pattern="%d-%m-%Y"),
                    "birthdate": self.faker.date(pattern="%d-%m-%Y"),
                    "email": self.faker.safe_email(),
                    "phone_number": self.faker.phone_number(),
                    "locale": self.faker.locale()
                }
                customer.save(post_cus_reg)

            logger.warning('customer Commits are successful after write job!',
                           extra=d)
        except Exception as e:
            logger.error(e, extra=d)



import redis
import sys
from custom import faker_options_container
from helpers import fake2db_logger, rnd_id_generator


logger, extra_information = fake2db_logger()
d = extra_information

try:
    from faker import Factory
except ImportError:
    logger.error('faker package not found onto python packages, please run : \
    pip install -r requirements.txt on the root of the project')


class Fake2dbRedisHandler():
    faker = Factory.create()

    def fake2db_redis_initiator(self, host, port, number_of_rows, name=None, custom=None):
        '''Main handler for the operation
        '''

        client, pipe = self.database_caller_creator(host, port, name)

        if custom:
            self.custom_db_creator(number_of_rows, pipe, custom)
            client.save()
            sys.exit(0)

        self.data_filler_simple_registration(number_of_rows, pipe)
        self.data_filler_detailed_registration(number_of_rows, pipe)
        self.data_filler_company(number_of_rows, pipe)
        self.data_filler_user_agent(number_of_rows, pipe)
        self.data_filler_customer(number_of_rows, pipe)

        client.save()

    def custom_db_creator(self, number_of_rows, pipe, custom):
        try:
            custom_d = faker_options_container()
            for c in custom:
                if custom_d.get(c):
                    logger.warning("fake2db found valid custom key provided: %s" % c, extra=d)
                else:
                    logger.error("fake2db does not support the custom key you provided.", extra=d )
                    sys.exit(1)

            for i in range(0, number_of_rows):
                dict_c = {}
                for c in custom:
                    dict_c[c] = getattr(self.faker, c)()
                    
                pipe.hmset('custom:%s' % i, dict_c)
                
            pipe.execute()
            
            logger.warning('custom Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)
            
    def database_caller_creator(self, host, port, name=None):
        '''creates a redis connection object
        which will be later used to modify the db
        '''

        name = name or 0
        client = redis.StrictRedis(host=host, port=port, db=name)
        pipe = client.pipeline(transaction=False)
        return client, pipe

    def data_filler_simple_registration(self, number_of_rows, pipe):
        '''creates keys with simple regis. information
        '''

        try:
            for i in range(number_of_rows):
                pipe.hmset('simple_registration:%s' % i, {
                    'id': rnd_id_generator(self),
                    'email': self.faker.safe_email(),
                    'password': self.faker.md5(raw_output=False)
                })
            pipe.execute()
            logger.warning('simple_registration Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_detailed_registration(self, number_of_rows, pipe):
        '''creates keys with detailed regis. information
        '''

        try:
            for i in range(number_of_rows):
                pipe.hmset('detailed_registration:%s' % i, {
                    'id': rnd_id_generator(self),
                    'email': self.faker.safe_email(),
                    'password': self.faker.md5(raw_output=False),
                    'lastname': self.faker.last_name(),
                    'name': self.faker.first_name(),
                    'address': self.faker.address(),
                    'phone': self.faker.phone_number()
                })
            pipe.execute()
            logger.warning('detailed_registration Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_user_agent(self, number_of_rows, pipe):
        '''creates keys with user agent data
        '''

        try:
            for i in range(number_of_rows):
                pipe.hmset('user_agent:%s' % i, {
                    'id': rnd_id_generator(self),
                    'ip': self.faker.ipv4(),
                    'countrycode': self.faker.country_code(),
                    'useragent': self.faker.user_agent()
                })
            pipe.execute()
            logger.warning('user_agent Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_company(self, number_of_rows, pipe):
        '''creates keys with company data
        '''

        try:
            for i in range(number_of_rows):
                pipe.hmset('company:%s' % i, {
                    'id': rnd_id_generator(self),
                    'name': self.faker.company(),
                    'date': self.faker.date(pattern="%d-%m-%Y"),
                    'email': self.faker.company_email(),
                    'domain': self.faker.safe_email(),
                    'city': self.faker.city()
                })
            pipe.execute()
            logger.warning('companies Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)

    def data_filler_customer(self, number_of_rows, pipe):
        '''creates keys with customer data
        '''

        try:
            for i in range(number_of_rows):
                pipe.hmset('customer:%s' % i, {
                    'id': rnd_id_generator(self),
                    'name': self.faker.first_name(),
                    'lastname': self.faker.last_name(),
                    'address': self.faker.address(),
                    'country': self.faker.country(),
                    'city': self.faker.city(),
                    'registry_date': self.faker.date(pattern="%d-%m-%Y"),
                    'birthdate': self.faker.date(pattern="%d-%m-%Y"),
                    'email': self.faker.safe_email(),
                    'phone_number': self.faker.phone_number(),
                    'locale': self.faker.locale()
                })
            pipe.execute()
            logger.warning('customer Commits are successful after write job!', extra=d)

        except Exception as e:
            logger.error(e, extra=d)



import sys
from custom import faker_options_container
from helpers import fake2db_logger, str_generator, rnd_id_generator


logger, extra_information = fake2db_logger()

try:
    import mysql.connector
except ImportError:
    logger.error(
        'MySql Connector/Python not found on sys, '
        'you need to get it : http://dev.mysql.com/downloads/connector/python/', extra=extra_information)

try:
    from faker import Factory
except ImportError:
    logger.error('faker package not found onto python packages, please run : \
    pip install -r requirements.txt  \
    on the root of the project', extra=extra_information)


class Fake2dbMySqlHandler():
    faker = Factory.create()

    def fake2db_mysql_initiator(self, host, port, password, username, number_of_rows, name=None, custom=None):
        '''Main handler for the operation
        '''
        rows = number_of_rows

        if name:
            cursor, conn = self.database_caller_creator(host, port, password, username, name)
        else:
            cursor, conn = self.database_caller_creator(host, port, password, username)

        if custom:
            self.custom_db_creator(rows, cursor, conn, custom)
            cursor.close()
            conn.close()
            sys.exit(0)

        tables = self.mysql_table_creator()
        keys = tables.keys()

        for key in keys:
            try:
                cursor.execute(tables[key])
                conn.commit()
            except mysql.connector.Error as err:
                logger.error(err.msg, extra=extra_information)
            else:
                logger.info("OK", extra=extra_information)

        logger.warning('Table creation ops finished', extra=extra_information)

        self.data_filler_simple_registration(rows, cursor, conn)
        self.data_filler_detailed_registration(rows, cursor, conn)
        self.data_filler_company(rows, cursor, conn)
        self.data_filler_user_agent(rows, cursor, conn)
        self.data_filler_customer(rows, cursor, conn)
        cursor.close()
        conn.close()

    def database_caller_creator(self, host, port, password, username, name=None):
        '''creates a mysql db
        returns the related connection object
        which will be later used to spawn the cursor
        '''
        cursor = None
        conn = None

        try:
            if name:
                db = name
            else:
                db = 'mysql_' + str_generator(self)

            conn = mysql.connector.connect(user=username, host=host, port=port, password=password)
            cursor = conn.cursor()
            cursor.execute('CREATE DATABASE IF NOT EXISTS ' + db)
            cursor.execute('USE ' + db)
            logger.warning('Database created and opened succesfully: %s' % db, extra=extra_information)

        except mysql.connector.Error as err:
            logger.error(err.msg, extra=extra_information)
            sys.exit(1)

        return cursor, conn

    def mysql_table_creator(self):
        '''Create all the tables in one method
        '''
        tables = {}

        tables['simple_registration'] = (
            "CREATE TABLE `simple_registration` ("
            "  `id` varchar(300) NOT NULL,"
            "  `email` varchar(300) NOT NULL,"
            "  `password` varchar(300) NOT NULL,"
            "  PRIMARY KEY (`id`)"
            ") ENGINE=InnoDB")

        tables['detailed_registration'] = (
            "CREATE TABLE `detailed_registration` ("
            "  `id` varchar(300) NOT NULL,"
            "  `email` varchar(300) NOT NULL,"
            "  `password` varchar(300) NOT NULL,"
            "  `lastname` varchar(300) NOT NULL,"
            "  `name` varchar(300) NOT NULL,"
            "  `address` varchar(300) NOT NULL,"
            "  `phone` varchar(300) NOT NULL,"
            "  PRIMARY KEY (`id`)"
            ") ENGINE=InnoDB")

        tables['user_agent'] = (
            "CREATE TABLE `user_agent` ("
            "  `id` varchar(300) NOT NULL,"
            "  `ip` varchar(300) NOT NULL,"
            "  `countrycode` varchar(300) NOT NULL,"
            "  `useragent` varchar(300) NOT NULL,"
            "  PRIMARY KEY (`id`)"
            ") ENGINE=InnoDB")

        tables['company'] = (
            "CREATE TABLE `company` ("
            "  `id` varchar(300) NOT NULL,"
            "  `name` varchar(300) NOT NULL,"
            "  `sdate` date NOT NULL,"
            "  `email` varchar(300) NOT NULL,"
            "  `domain` varchar(300) NOT NULL,"
            "  `city` varchar(300) NOT NULL,"
            "  PRIMARY KEY (`id`)"
            ") ENGINE=InnoDB")

        tables['customer'] = (
            "CREATE TABLE `customer` ("
            "  `id` varchar(300) NOT NULL,"
            "  `name` varchar(300) NOT NULL,"
            "  `lastname` varchar(300) NOT NULL,"
            "  `address` varchar(300) NOT NULL,"
            "  `country` varchar(300) NOT NULL,"
            "  `city` varchar(300) NOT NULL,"
            "  `registry_date` varchar(300) NOT NULL,"
            "  `birthdate` varchar(300) NOT NULL,"
            "  `email` varchar(300) NOT NULL,"
            "  `phone_number` varchar(300) NOT NULL,"
            "  `locale` varchar(300) NOT NULL,"
            "  PRIMARY KEY (`id`)"
            ") ENGINE=InnoDB")

        return tables

    def custom_db_creator(self, number_of_rows, cursor, conn, custom):
        '''creates and fills the table with simple regis. information
        '''

        custom_d = faker_options_container()
        sqlst = "CREATE TABLE `custom` (`id` varchar(300) NOT NULL,"
        custom_payload = "INSERT INTO custom (id,"
        
        # form the sql query that will set the db up
        for c in custom:
            if custom_d.get(c):
                sqlst += " `" + c + "` " + custom_d[c] + ","
                custom_payload += " " + c + ","
                logger.warning("fake2db found valid custom key provided: %s" % c, extra=extra_information)
            else:
                logger.error("fake2db does not support the custom key you provided.", extra=extra_information)
                sys.exit(1)
                
        # the indice thing is for trimming the last extra comma
        sqlst += " PRIMARY KEY (`id`)) ENGINE=InnoDB"
        custom_payload = custom_payload[:-1]
        custom_payload += ") VALUES (%s, "
        
        for i in range(0, len(custom)):
            custom_payload += "%s, "
        custom_payload = custom_payload[:-2] + ")"
        
        try:
            cursor.execute(sqlst)
            conn.commit()
        except mysql.connector.Error as err:
            logger.error(err.msg, extra=extra_information)

        multi_lines = []
        try:
            for i in range(0, number_of_rows):
                multi_lines.append([rnd_id_generator(self)])
                for c in custom:
                    multi_lines[i].append(getattr(self.faker, c)())
            
            cursor.executemany(custom_payload, multi_lines)
            conn.commit()
            logger.warning('custom Commits are successful after write job!', extra=extra_information)
        except Exception as e:
            logger.error(e, extra=extra_information)
    
    def data_filler_simple_registration(self, number_of_rows, cursor, conn):
        '''creates and fills the table with simple regis. information
        '''
        simple_registration_data = []
        
        try:
            for i in range(0, number_of_rows):
                simple_registration_data.append((
                    rnd_id_generator(self), self.faker.safe_email(), self.faker.md5(raw_output=False)))
                
            simple_registration_payload = ("INSERT INTO simple_registration "
                                               "(id, email, password) "
                                               "VALUES (%s, %s, %s)")
            
            cursor.executemany(simple_registration_payload, simple_registration_data)
            conn.commit()

            logger.warning('simple_registration Commits are successful after write job!', extra=extra_information)
        except Exception as e:
            logger.error(e, extra=extra_information)

    def data_filler_detailed_registration(self, number_of_rows, cursor, conn):
        '''creates and fills the table with detailed regis. information
        '''
        detailed_registration_data = []
        
        try:
            for i in range(0, number_of_rows):
                detailed_registration_data.append((
                    rnd_id_generator(self), self.faker.safe_email(), self.faker.md5(raw_output=False),
                    self.faker.last_name(), self.faker.first_name(), self.faker.address(), self.faker.phone_number()))
            detailed_registration_payload = ("INSERT INTO detailed_registration "
                                             "(id, email, password, lastname, name,"
                                             "address, phone) "
                                             "VALUES (%s, %s, %s, %s, %s, %s, %s)")
            
            cursor.executemany(detailed_registration_payload, detailed_registration_data)
            conn.commit()

            logger.warning('detailed_registration Commits are successful after write job!', extra=extra_information)

        except Exception as e:
            logger.error(e, extra=extra_information)

    def data_filler_user_agent(self, number_of_rows, cursor, conn):
        '''creates and fills the table with user agent data
        '''
        user_agent_data = []
        
        try:
            for i in range(0, number_of_rows):
                user_agent_data.append((rnd_id_generator(self), self.faker.ipv4(),
                                        self.faker.country_code(), self.faker.user_agent()))
                
            user_agent_payload = ("INSERT INTO user_agent "
                                  "(id, ip, countrycode, useragent) "
                                  "VALUES (%s, %s, %s, %s)")
            
            cursor.executemany(user_agent_payload, user_agent_data)
            conn.commit()
            logger.warning('user_agent Commits are successful after write job!', extra=extra_information)
        except Exception as e:
            logger.error(e, extra=extra_information)

    def data_filler_company(self, number_of_rows, cursor, conn):
        '''creates and fills the table with company data
        '''
        companies_data = []
        
        try:
            for i in range(0, number_of_rows):
                
                companies_data.append((rnd_id_generator(self), self.faker.company(), self.faker.date(pattern="%Y-%m-%d"),
                                  self.faker.company_email(), self.faker.safe_email(), self.faker.city()))
                
            companies_payload = ("INSERT INTO company "
                                 "(id, name, sdate, email, domain, city) "
                                 "VALUES (%s, %s, %s, %s, %s, %s)")
            
            cursor.executemany(companies_payload, companies_data)
            conn.commit()
            logger.warning('companies Commits are successful after write job!', extra=extra_information)
        except Exception as e:
            logger.error(e, extra=extra_information)

    def data_filler_customer(self, number_of_rows, cursor, conn):
        '''creates and fills the table with customer
        '''
        customer_data = []
        
        try:
            for i in range(0, number_of_rows):
                
                customer_data.append((
                    rnd_id_generator(self), self.faker.first_name(), self.faker.last_name(), self.faker.address(),
                    self.faker.country(), self.faker.city(), self.faker.date(pattern="%d-%m-%Y"),
                    self.faker.date(pattern="%d-%m-%Y"), self.faker.safe_email(), self.faker.phone_number(),
                    self.faker.locale()))
                
            customer_payload = ("INSERT INTO customer "
                                "(id, name, lastname, address, country, city, registry_date, birthdate, email, "
                                "phone_number, locale)"
                                "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)")
            cursor.executemany(customer_payload, customer_data)
            conn.commit()
            logger.warning('detailed_registration Commits are successful after write job!', extra=extra_information)
        except Exception as e:
            logger.error(e, extra=extra_information)



import argparse
import getpass
import subprocess
import time
import sys
from custom import faker_options_container
from helpers import fake2db_logger

logger, extra_information = fake2db_logger()


class InstantiateDBHandlerException(Exception):
    '''An Exception at the instantiation of the handler '''


class MissingDependencyException(Exception):
    '''An Exception to be thrown if the dependencies are missing'''


def _mysqld_process_checkpoint():
    '''this helper method checks if
    mysql server is available in the sys
    if not fires up one
    '''
    try:
        subprocess.check_output("pgrep mysqld", shell=True)
    except Exception:
        logger.warning(
            'Your mysql server is offline, fake2db will try to launch it now!',
            extra=extra_information)
        # close_fds = True argument is the flag that is responsible
        # for Popen to launch the process completely independent
        subprocess.Popen("mysqld", close_fds=True, shell=True)
        time.sleep(3)


def _mongodb_process_checkpoint():
    '''this helper method checks if
    mongodb server is available in the sys
    if not fires up one
    '''
    try:
        subprocess.check_output("pgrep mongod", shell=True)
    except Exception:
        logger.warning(
            'Your mongodb server is offline, fake2db will try to launch it now!',
            extra=extra_information)
        # close_fds = True argument is the flag that is responsible
        # for Popen to launch the process completely independent
        subprocess.Popen("mongod", close_fds=True, shell=True)
        time.sleep(3)


def _couchdb_process_checkpoint():
    '''this helper method checks if
    couchdb server is available in the sys
    if not fires up one
    '''
    try:
        subprocess.check_output("curl localhost:5984", shell=True)
    except Exception:
        logger.warning('Your couchdb server is offline',
                       extra=extra_information)
        # close_fds = True argument is the flag that is responsible
        # for Popen to launch the process completely independent
        subprocess.Popen("couchdb", close_fds=True, shell=True)
        time.sleep(3)


def _redis_process_checkpoint(host, port):
    '''this helper method checks if
    redis server is available in the sys
    if not fires up one
    '''
    try:
        subprocess.check_output("pgrep redis", shell=True)
    except Exception:
        logger.warning(
            'Your redis server is offline, fake2db will try to launch it now!',
            extra=extra_information)
        # close_fds = True argument is the flag that is responsible
        # for Popen to launch the process completely independent
        subprocess.Popen("redis-server --bind %s --port %s" % (host, port),
                         close_fds=True,
                         shell=True)
        time.sleep(3)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--rows", help="Amount of rows desired per table",
                        type=int)
    parser.add_argument(
        "--db",
        help=
        "Db type for creation: sqlite, mysql, postgresql, mongodb, redis, couchdb, to be expanded")
    parser.add_argument("--name", help="The name to the db to be generated")
    parser.add_argument("--host", help="Hostname of db")
    parser.add_argument("--port", help="Port of db", type=int)
    parser.add_argument("--username", help="Username")
    parser.add_argument("--password", help="Password")
    parser.add_argument("--custom", nargs='+', help="Custom schema for db generation, supports functions that fake-factory provides, see fake2db github repository for options https://github.com/emirozer/fake2db")


    args = parser.parse_args()

    if not args.rows or not args.db:
        logger.error('Please use with --help argument for usage information!',
                     extra=extra_information)

    else:
        logger.info('arguments found(rows and db), starting faking!!',
                    extra=extra_information)
        logger.warning('Rows argument : %s', args.rows,
                       extra=extra_information)
        logger.info('DB argument : %s', args.db, extra=extra_information)

        if args.custom:
            custom_d = faker_options_container()
            for c in args.custom:
                if custom_d.get(c):
                    logger.info("fake2db found valid custom key provided: %s" % c, extra=extra_information)
                else:
                    logger.error("fake2db does not support the custom key you provided: %s" % c, extra=extra_information )
                    sys.exit(1)
                
        if args.db == 'sqlite':
            try:
                from sqlite_handler import Fake2dbSqliteHandler
                fake_sqlite_handler = Fake2dbSqliteHandler()
            except Exception:
                raise InstantiateDBHandlerException
            if args.name and args.custom:
                fake_sqlite_handler.fake2db_sqlite_initiator(args.rows,
                                                             args.name, args.custom)
            elif args.custom:
                fake_sqlite_handler.fake2db_sqlite_initiator(args.rows, None, args.custom)
            else:
                fake_sqlite_handler.fake2db_sqlite_initiator(args.rows)

        elif args.db == 'mysql':
            try:
                from mysql_handler import Fake2dbMySqlHandler
                fake_mysql_handler = Fake2dbMySqlHandler()
            except Exception:
                raise InstantiateDBHandlerException
            _mysqld_process_checkpoint()
            host = args.host or "127.0.0.1"
            port = args.port or 3306
            username = args.username or getpass.getuser()
            if args.name and args.custom:
                fake_mysql_handler.fake2db_mysql_initiator(
                    host, port, args.password, username, args.rows, args.name, args.custom)
            elif args.custom:
                fake_mysql_handler.fake2db_mysql_initiator(
                    host, port, args.password, username, args.rows, None, args.custom)
            else:
                fake_mysql_handler.fake2db_mysql_initiator(
                    host, port, args.password, username, args.rows, None, None)

        elif args.db == 'postgresql':
            try:
                import psycopg2
            except ImportError:
                raise MissingDependencyException(
                    'psycopg2 package not found on the python packages, please run: pip install psycopg2')

            try:
                from postgresql_handler import Fake2dbPostgresqlHandler
                fake_postgresql_handler = Fake2dbPostgresqlHandler()
            except Exception:
                raise InstantiateDBHandlerException
            host = args.host or "localhost"
            port = args.port or 5432
            username = args.username or getpass.getuser()
            custom = args.custom or None
            fake_postgresql_handler.fake2db_initiator(host=host, port=port,
                                                      username=username,
                                                      password=args.password,
                                                      number_of_rows=args.rows,
                                                      name=args.name,
                                                      custom=custom)

        elif args.db == 'mongodb':
            try:
                import pymongo
            except ImportError:
                raise MissingDependencyException(
                    'pymongo package not found on the python packages, please run: pip install pymongo')

            try:
                from mongodb_handler import Fake2dbMongodbHandler
                fake_mongodb_handler = Fake2dbMongodbHandler()
            except Exception:
                raise InstantiateDBHandlerException
            _mongodb_process_checkpoint()
            host = args.host or "localhost"
            port = args.port or 27017

            if args.name and args.custom:
                fake_mongodb_handler.fake2db_mongodb_initiator(
                    host, port, args.rows, args.name, args.custom)
            elif args.custom:
                fake_mongodb_handler.fake2db_mongodb_initiator(
                    host, port, args.rows, None, args.custom)
            else:
                fake_mongodb_handler.fake2db_mongodb_initiator(host, port,
                                                               args.rows)

        elif args.db == 'couchdb':
            try:
                import couchdb
            except ImportError:
                raise MissingDependencyException(
                    'couchdb package not found on the python packages, please run: pip install couchdb')

            try:
                from couchdb_handler import Fake2dbCouchdbHandler
                fake_couchdb_handler = Fake2dbCouchdbHandler()
            except Exception:
                raise InstantiateDBHandlerException
            _couchdb_process_checkpoint()
            
            if args.name and args.custom:
                fake_couchdb_handler.fake2db_couchdb_initiator(
                    args.rows, args.name, args.custom)
            elif args.custom:
                fake_couchdb_handler.fake2db_couchdb_initiator(
                    args.rows, None, args.custom)
            else:
                fake_couchdb_handler.fake2db_couchdb_initiator(args.rows)
                
        elif args.db == 'redis':
            if args.name and (not args.name.isdigit() or int(args.name) < 0):
                logger.error('redis db name must be a non-negative integer',
                             extra=extra_information)
                return

            try:
                import redis
            except ImportError:
                raise MissingDependencyException(
                    'redis package not found on the python packages, please run: pip install redis')

            try:
                from redis_handler import Fake2dbRedisHandler
                fake_redis_handler = Fake2dbRedisHandler()
            except Exception:
                raise InstantiateDBHandlerException
            host = args.host or "localhost"
            port = args.port or 6379
            _redis_process_checkpoint(host, port)
            if args.name and args.custom:
                fake_redis_handler.fake2db_redis_initiator(
                    host, port, args.rows, args.name, args.custom)
            elif args.custom:
                fake_redis_handler.fake2db_redis_initiator(
                    host, port, args.rows, None, args.custom)
            else:
                fake_redis_handler.fake2db_redis_initiator(host, port,
                                                           args.rows)

        else:
            logger.error(
                'Wrong arg for db parameter. Valid ones : sqlite - mysql - postgresql - mongodb - redis',
                extra=extra_information)


if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
import os

setup(
    name='fake2db',
    version='0.5.0',
    author='Emir Ozer',
    author_email='emirozer@yandex.com',
    url='https://github.com/emirozer/fake2db',
    description=
    'Generate test databases filled with fake data (NOW CUSTOM SCHEMA CREATION SUPPORTED)(current support - sqlite, mysql, postgresql, mongodb, redis, couchdb)',
    long_description=os.path.join(os.path.dirname(__file__), 'README.md'),
    packages=find_packages(exclude=[]),
    entry_points={'console_scripts': ['fake2db = fake2db.fake2db:main']},
    install_requires=[
        'fake-factory>=0.5.3',
    ],
    include_package_data=True,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ], )
